Package 'EMfit'
| Title: |
An Infrastructure for Latent Variable Model Fitting using EM
Algorithms |
| Description: |
The package contains the boilerplate code for estimating
latent variable models by maximum marginal likelihood using EM
algorithms. The code is generic and thus not optimised for
particular models. The package supports fitting latent class or
finite mixture models using simple EM algorithms and (to some
degree) latent trait or continous mixture models using Monte
Carlo EM algorithms. Only importance sampling is supported for
MCEM. However, it implements automatic sample size adjustment
using the approach of Caffo Jank and Jones. |
| Authors: |
Martin Elff |
| Maintainer: |
Martin Elff <[email protected]> |
| License: |
GPL |
| Version: |
0.2.1 |
| Built: |
2026-05-09 08:02:53 UTC |
| Source: |
https://github.com/melff/EMfit |
Help Index